pub struct IotaSystemStateSummaryV1 {Show 34 fields
pub epoch: u64,
pub protocol_version: u64,
pub system_state_version: u64,
pub iota_total_supply: u64,
pub iota_treasury_cap_id: ObjectID,
pub storage_fund_total_object_storage_rebates: u64,
pub storage_fund_non_refundable_balance: u64,
pub reference_gas_price: u64,
pub safe_mode: bool,
pub safe_mode_storage_charges: u64,
pub safe_mode_computation_rewards: u64,
pub safe_mode_storage_rebates: u64,
pub safe_mode_non_refundable_storage_fee: u64,
pub epoch_start_timestamp_ms: u64,
pub epoch_duration_ms: u64,
pub min_validator_count: u64,
pub max_validator_count: u64,
pub min_validator_joining_stake: u64,
pub validator_low_stake_threshold: u64,
pub validator_very_low_stake_threshold: u64,
pub validator_low_stake_grace_period: u64,
pub total_stake: u64,
pub active_validators: Vec<IotaValidatorSummary>,
pub pending_active_validators_id: ObjectID,
pub pending_active_validators_size: u64,
pub pending_removals: Vec<u64>,
pub staking_pool_mappings_id: ObjectID,
pub staking_pool_mappings_size: u64,
pub inactive_pools_id: ObjectID,
pub inactive_pools_size: u64,
pub validator_candidates_id: ObjectID,
pub validator_candidates_size: u64,
pub at_risk_validators: Vec<(IotaAddress, u64)>,
pub validator_report_records: Vec<(IotaAddress, Vec<IotaAddress>)>,
}Expand description
This is the JSON-RPC type for the
IotaSystemStateSummaryV1
object.
Fields
epoch: u64The current epoch ID, starting from 0.
protocol_version: u64The current protocol version, starting from 1.
system_state_version: u64The current version of the system state data structure type.
iota_total_supply: u64The current IOTA supply.
iota_treasury_cap_id: ObjectIDThe TreasuryCap<IOTA> object ID.
storage_fund_total_object_storage_rebates: u64The storage rebates of all the objects on-chain stored in the storage fund.
storage_fund_non_refundable_balance: u64The non-refundable portion of the storage fund coming from non-refundable storage rebates and any leftover staking rewards.
reference_gas_price: u64The reference gas price for the current epoch.
safe_mode: boolWhether the system is running in a downgraded safe mode due to a non-recoverable bug. This is set whenever we failed to execute advance_epoch, and ended up executing advance_epoch_safe_mode. It can be reset once we are able to successfully execute advance_epoch.
safe_mode_storage_charges: u64Amount of storage charges accumulated (and not yet distributed) during safe mode.
safe_mode_computation_rewards: u64Amount of computation rewards accumulated (and not yet distributed) during safe mode.
safe_mode_storage_rebates: u64Amount of storage rebates accumulated (and not yet burned) during safe mode.
safe_mode_non_refundable_storage_fee: u64Amount of non-refundable storage fee accumulated during safe mode.
epoch_start_timestamp_ms: u64Unix timestamp of the current epoch start
epoch_duration_ms: u64The duration of an epoch, in milliseconds.
min_validator_count: u64Minimum number of active validators at any moment. We do not allow the number of validators in any epoch to go under this.
max_validator_count: u64Maximum number of active validators at any moment. We do not allow the number of validators in any epoch to go above this.
min_validator_joining_stake: u64Lower-bound on the amount of stake required to become a validator.
validator_low_stake_threshold: u64Validators with stake amount below validator_low_stake_threshold are
considered to have low stake and will be escorted out of the
validator set after being below this threshold for more than
validator_low_stake_grace_period number of epochs.
validator_very_low_stake_threshold: u64Validators with stake below validator_very_low_stake_threshold will be
removed immediately at epoch change, no grace period.
validator_low_stake_grace_period: u64A validator can have stake below validator_low_stake_threshold
for this many epochs before being kicked out.
total_stake: u64Total amount of stake from all active validators at the beginning of the epoch.
active_validators: Vec<IotaValidatorSummary>The list of active validators in the current epoch.
pending_active_validators_id: ObjectIDID of the object that contains the list of new validators that will join at the end of the epoch.
pending_active_validators_size: u64Number of new validators that will join at the end of the epoch.
pending_removals: Vec<u64>Removal requests from the validators. Each element is an index
pointing to active_validators.
staking_pool_mappings_id: ObjectIDID of the object that maps from staking pool’s ID to the iota address of a validator.
staking_pool_mappings_size: u64Number of staking pool mappings.
inactive_pools_id: ObjectIDID of the object that maps from a staking pool ID to the inactive validator that has that pool as its staking pool.
inactive_pools_size: u64Number of inactive staking pools.
validator_candidates_id: ObjectIDID of the object that stores preactive validators, mapping their
addresses to their Validator structs.
validator_candidates_size: u64Number of preactive validators.
at_risk_validators: Vec<(IotaAddress, u64)>Map storing the number of epochs for which each validator has been below the low stake threshold.
validator_report_records: Vec<(IotaAddress, Vec<IotaAddress>)>A map storing the records of validator reporting each other.