pub struct IotaValidatorSummary {Show 38 fields
pub iota_address: IotaAddress,
pub authority_pubkey_bytes: Vec<u8>,
pub network_pubkey_bytes: Vec<u8>,
pub protocol_pubkey_bytes: Vec<u8>,
pub proof_of_possession_bytes: Vec<u8>,
pub name: String,
pub description: String,
pub image_url: String,
pub project_url: String,
pub net_address: String,
pub p2p_address: String,
pub primary_address: String,
pub next_epoch_authority_pubkey_bytes: Option<Vec<u8>>,
pub next_epoch_proof_of_possession: Option<Vec<u8>>,
pub next_epoch_network_pubkey_bytes: Option<Vec<u8>>,
pub next_epoch_protocol_pubkey_bytes: Option<Vec<u8>>,
pub next_epoch_net_address: Option<String>,
pub next_epoch_p2p_address: Option<String>,
pub next_epoch_primary_address: Option<String>,
pub voting_power: u64,
pub operation_cap_id: ObjectId,
pub gas_price: u64,
pub commission_rate: u64,
pub effective_commission_rate: Option<u64>,
pub next_epoch_stake: u64,
pub next_epoch_gas_price: u64,
pub next_epoch_commission_rate: u64,
pub staking_pool_id: ObjectId,
pub staking_pool_activation_epoch: Option<u64>,
pub staking_pool_deactivation_epoch: Option<u64>,
pub staking_pool_iota_balance: u64,
pub rewards_pool: u64,
pub pool_token_balance: u64,
pub pending_stake: u64,
pub pending_total_iota_withdraw: u64,
pub pending_pool_token_withdraw: u64,
pub exchange_rates_id: ObjectId,
pub exchange_rates_size: u64,
}Expand description
This is the JSON-RPC type for the IOTA validator. It flattens all inner structures to top-level fields so that they are decoupled from the internal definitions.
Fields
iota_address: IotaAddressnetwork_pubkey_bytes: Vec<u8>protocol_pubkey_bytes: Vec<u8>proof_of_possession_bytes: Vec<u8>name: Stringdescription: Stringimage_url: Stringproject_url: Stringnet_address: Stringp2p_address: Stringprimary_address: Stringnext_epoch_proof_of_possession: Option<Vec<u8>>next_epoch_network_pubkey_bytes: Option<Vec<u8>>next_epoch_protocol_pubkey_bytes: Option<Vec<u8>>next_epoch_net_address: Option<String>next_epoch_p2p_address: Option<String>next_epoch_primary_address: Option<String>voting_power: u64operation_cap_id: ObjectIdgas_price: u64commission_rate: u64effective_commission_rate: Option<u64>next_epoch_stake: u64next_epoch_gas_price: u64next_epoch_commission_rate: u64staking_pool_id: ObjectIdID of the staking pool object.
staking_pool_activation_epoch: Option<u64>The epoch at which this pool became active.
staking_pool_deactivation_epoch: Option<u64>The epoch at which this staking pool ceased to be active. None =
{pre-active, active},
staking_pool_iota_balance: u64The total number of IOTA tokens in this pool.
rewards_pool: u64The epoch stake rewards will be added here at the end of each epoch.
pool_token_balance: u64Total number of pool tokens issued by the pool.
pending_stake: u64Pending stake amount for this epoch.
pending_total_iota_withdraw: u64Pending stake withdrawn during the current epoch, emptied at epoch boundaries.
pending_pool_token_withdraw: u64Pending pool token withdrawn during the current epoch, emptied at epoch boundaries.
exchange_rates_id: ObjectIdID of the exchange rate table object.
exchange_rates_size: u64Number of exchange rates in the table.